function isLetterOrEqual(n, maxValue) {
  return +n <= +maxValue;
}

function isGreaterOrEqual(n, minValue) {
  return +n >= +minValue;
}

function isIncrementAllowed(testModel, type, maxValue, maxLen, intPartMaxLen) {
  /* reject decrement if max length exceeded */
  if (type === 'integer' && testModel.length > maxLen) {
    return false;
  }

  if (type === 'float') {
    const intPart = testModel.split('.')[0];

    if (intPart.length > intPartMaxLen) {
      return false;
    }
  }

  if (isLetterOrEqual(testModel, maxValue)) {
    return true;
  }

  return false;
}

function isDecrementAllowed(testModel, type, minValue, maxLen, intPartMaxLen) {
  if (+testModel < 0) {
    /* reject decrement if max length exceeded */
    if (type === 'integer') {
      if (maxLen === 1) {
        if (testModel.length > (maxLen + 1)) return false;
      } else if (testModel.length > maxLen) return false;
    }

    if (type === 'float') {
      const intPart = testModel.split('.')[0];

      if (intPart.length > intPartMaxLen) {
        return false;
      }
    }
  }

  if (isGreaterOrEqual(testModel, minValue)) {
    return true;
  }

  return false;
}

function isCorrectFloat(n, unsigned, intPartMaxLen, floatPartMaxLen) {
  const reFloatUnsigned = new RegExp(`\\d{1,${intPartMaxLen}}(\\.\\d{0,${floatPartMaxLen}})?$`, 'g');
  const reFloatSigned = new RegExp(`^-?\\d{1,${intPartMaxLen}}(\\.\\d{0,${floatPartMaxLen}})?$`, 'g');

  let regExpToUse = '';

  if (unsigned) {
    regExpToUse = reFloatUnsigned;
  } else {
    regExpToUse = reFloatSigned;
  }

  const matches = String(n).match(regExpToUse);

  if (matches) {
    return String(matches[0]) === String(n);
  }
  return false;
}

function isCorrectInteger(n, unsigned, maxLen) {
  const reIntegerUnsigned = new RegExp(`^(\\d){1,${maxLen}}$`, 'g');
  const reIntegerSigned = new RegExp(`^-?(\\d){1,${maxLen}}$`, 'g');

  let regExpToUse = '';

  if (unsigned) {
    regExpToUse = reIntegerUnsigned;
  } else {
    regExpToUse = reIntegerSigned;
  }

  const matches = String(n).match(regExpToUse);

  if (matches) {
    return String(matches[0]) === String(n);
  }
  return false;
}

export {
  isLetterOrEqual,
  isGreaterOrEqual,
  isIncrementAllowed,
  isDecrementAllowed,
  isCorrectFloat,
  isCorrectInteger,
};
